@@ -1,6 +1,13 @@
+# $Id: Get_nice.pm,v 1.7 2004/01/03 14:52:53 epaepa Exp $
+#
 # Library to wrap LWP::Simple to put in a random delay between
-# requests.  We really should be using LWP::RobotUI but this is better
-# than nothing.
+# requests and to set User-Agent.  We really should be using
+# LWP::RobotUI but this is better than nothing.
+#
+# If you're sure your app doesn't need a random delay (because it is
+# fetching from a site designed for that purpose) then set
+# $XMLTV::Get_nice::Delay to zero, or a value in seconds.  This is the
+# maximum delay - on average the sleep will be half that.
 #
 # get_nice() is the function to call, however
 # XMLTV::Get_nice::get_nice_aux() is the one to cache with
@@ -10,7 +17,10 @@
 package XMLTV::Get_nice;
 use base 'Exporter';
 our @EXPORT = qw(get_nice);
-use LWP::Simple;
+use LWP::Simple qw($ua);
+use XMLTV;
+$ua->agent("xmltv/$XMLTV::VERSION");
+our $Delay = 5; # in seconds
 
 sub get_nice( $ ) {
     # This is to ensure scalar context, to work around weirdnesses
@@ -33,7 +43,7 @@ sub get_nice_aux( $ ) {
     # Be nice to the server.  Technically we don't need to do this
     # after the very last fetch, but sleeping every time is simpler.
     #
-    sleep(rand 5);
+    sleep(rand $Delay);
 
     return $r;
 }
