@@ -2,7 +2,8 @@
 # and also by Makefile.PL, so this file should not depend on any
 # nonstandard libraries.
 #
-
+# $Id: AskTerm.pm,v 1.6 2004/01/03 14:52:53 epaepa Exp $
+#
 package XMLTV::AskTerm;
 use strict;
 use base 'Exporter';
@@ -48,6 +49,23 @@ sub ask( $ )
     }
 }
 
+# Check for exact match, then for substring matching.
+sub match( $@ ) {
+    my ($choice, @options) = @_;
+    foreach (@options) {
+	return $_ if $_ eq $choice;
+    }
+    my @poss;
+    foreach (@options) {
+	push @poss, $_ if /\Q$choice\E/i;
+    }
+    if (@poss == 1) {
+	# Unambiguous substring match.
+	return $poss[0];
+    }
+    return undef;
+}
+
 # Ask a question where the answer is one of a set of alternatives.
 #
 # Parameters:
@@ -67,6 +85,10 @@ sub askQuestion( $$@ )
     croak "default $default not in options"
       if not grep { $_ eq $default } @options;
 
+    # Check no duplicates (required for later processing, maybe).
+    my %seen;
+    foreach (@options) { die "duplicate option $_" if $seen{$_}++ }
+
     my $options_size = length("@options");
     t "size of options: $options_size";
     my $all_digits = not ((my $tmp = join('', @options)) =~ tr/0-9//c);
@@ -78,20 +100,9 @@ sub askQuestion( $$@ )
 	    my $res=ask($str);
 	    return undef if not defined $res;
 	    return $default if $res eq '';
-
-	    # Check for exact match, then for substring matching.
-	    foreach (@options) {
-		return $_ if $_ eq $res;
+	    for (match($res, @options)) {
+		return $_ if defined;
 	    }
-	    my @poss;
-	    foreach (@options) {
-		push @poss, $_ if /\Q$res\E/i;
-	    }
-	    if (@poss == 1) {
-		# Unambiguous substring match.
-		return $poss[0];
-	    }
-
 	    print STDERR "invalid response, please choose one of ".join(',', @options)."\n\n";
 	}
     }
@@ -100,24 +111,45 @@ sub askQuestion( $$@ )
 	print STDERR "$question\n";
 	my $optnum = 0;
 	my (%num_to_choice, %choice_to_num);
+
+	# If any of the option strings happen to be numbers, and
+	# within the range of option numbers, arrange it so they're
+	# with the matching number.
+	#
+	my (@numbers, @others);
+	foreach (@options) {
+	    if (/^\d+$/ && $_ < @options) { push @numbers, $_ }
+	    else { push @others, $_ }
+	}
+	@options = ();
+	foreach (sort { $a <=> $b } @numbers) {
+	    push @options, splice @others, 0, $_ - @options;
+	    push @options, $_;
+	}
+	push @options, @others;
+
 	foreach (@options) {
-	    print STDERR "$optnum: $_\n";
 	    $num_to_choice{$optnum} = $_;
 	    $choice_to_num{$_} = $optnum;
 	    ++ $optnum;
 	}
 	$optnum--;
 	my $r=undef;
-	my $default_num = $choice_to_num{$default};
-	die if not defined $default_num;
-	until (defined $r) {
-	    $r = askQuestion('Select one:',
-			     $default_num, 0 .. $optnum);
-	    return undef if not defined $r;
-	    for ($num_to_choice{$r}) { return $_ if defined }
-	    print STDERR "invalid response, please choose one of "
-	      .0 .. $optnum."\n\n";
-	    undef $r;
+      ASK: for (;;) {
+	    # Present a numbered list of options, but accept either
+	    # numbers or the option names.
+	    #
+	    print STDERR "$_: $options[$_]\n" foreach 0 .. $#options;
+	    my $res = ask('choose one: ');
+	    # No default.
+
+	    foreach (0 .. $#options) {
+		return $num_to_choice{$_} if $res eq $_;
+	    }
+	    for (match($res, @options)) {
+		return $_ if defined;
+	    }
+	    print STDERR "invalid response, please choose one of the following:\n\n";
 	}
     }
 }
